@@ -154,7 +154,9 @@ validate_response <- function(request) {
 }
 
 unmarshal <- function(request) {
-  if (length(request$data) == 0) return(request)
+  if (length(request$data) == 0) {
+    return(request)
+  }
   request <- run(request, unmarshal)
   return(request)
 }
